"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var property_provider_1 = require("@aws-sdk/property-provider");
var protocol_timestamp_1 = require("@aws-sdk/protocol-timestamp");
exports.ENV_KEY = 'AWS_ACCESS_KEY_ID';
exports.ENV_SECRET = 'AWS_SECRET_ACCESS_KEY';
exports.ENV_SESSION = 'AWS_SESSION_TOKEN';
exports.ENV_EXPIRATION = 'AWS_CREDENTIAL_EXPIRATION';
/**
 * Source AWS credentials from known environment variables. If either the
 * `AWS_ACCESS_KEY_ID` or `AWS_SECRET_ACCESS_KEY` environment variable is not
 * set in this process, the provider will return a rejected promise.
 */
function fromEnv() {
    return function () {
        var accessKeyId = process.env[exports.ENV_KEY];
        var secretAccessKey = process.env[exports.ENV_SECRET];
        var expiry = process.env[exports.ENV_EXPIRATION];
        if (accessKeyId && secretAccessKey) {
            return Promise.resolve({
                accessKeyId: accessKeyId,
                secretAccessKey: secretAccessKey,
                sessionToken: process.env[exports.ENV_SESSION],
                expiration: expiry ? protocol_timestamp_1.epoch(expiry) : undefined
            });
        }
        return Promise.reject(new property_provider_1.ProviderError('Unable to find environment variable credentials.'));
    };
}
exports.fromEnv = fromEnv;
//# sourceMappingURL=index.js.map